@@ -1,6 +1,6 @@
 package UI::Dialog;
 ###############################################################################
-#  Copyright (C) 2004  Kevin C. Krinke <kckrinke@opendoorsoftware.com>
+#  Copyright (C) 2015  Kevin C. Krinke <kevin@krinke.ca>
 #
 #  This library is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU Lesser General Public
@@ -22,7 +22,7 @@ use Carp;
 
 BEGIN {
     use vars qw($VERSION);
-    $VERSION = '1.08';
+    $VERSION = '1.11';
 }
 
 #::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
@@ -68,6 +68,11 @@ sub new {
     $self->_debug("ENV->UI_DIALOG: ".($ENV{'UI_DIALOG'}||'NULL'),2);
     unshift(@{$cfg->{'order'}},$ENV{'UI_DIALOG'}) if $ENV{'UI_DIALOG'};
 
+    $cfg->{'trust-input'} =
+      ( exists $cfg->{'trust-input'}
+        && $cfg->{'trust-input'}==1
+      ) ? 1 : 0;
+
     my @opts = ();
     foreach my $opt (keys(%$cfg)) { push(@opts,$opt,$cfg->{$opt}); }
 
@@ -228,7 +233,7 @@ sub dselect   { return(shift()->{'_ui_dialog'}->dselect(@_));   }
 
 =head1 NAME
 
-UI::Dialog
+UI::Dialog - wrapper for various dialog applications.
 
 =head1 SYNOPSIS
 
@@ -284,6 +289,8 @@ None
 
 =over 2
 
+=back
+
 =head2 new( @options )
 
 =over 4
@@ -347,12 +354,12 @@ decided during object creation.
 
 =back
 
-=back
-
 =head1 STATE METHODS
 
 =over 2
 
+=back
+
 =head2 state( )
 
 =over 4
@@ -387,10 +394,10 @@ a single SCALAR.
 
 =back
 
-=back
-
 =over 2
 
+=back
+
 =head2 ra( )
 
 =over 4
@@ -421,10 +428,10 @@ an ARRAY.
 
 =back
 
-=back
-
 =over 2
 
+=back
+
 =head2 rs( )
 
 =over 4
@@ -455,10 +462,10 @@ a SCALAR.
 
 =back
 
-=back
-
 =over 2
 
+=back
+
 =head2 rv( )
 
 =over 4
@@ -489,12 +496,12 @@ a SCALAR.
 
 =back
 
-=back
-
 =head1 WIDGET METHODS
 
 =over 2
 
+=back
+
 =head2 yesno( )
 
 =over 4
@@ -529,10 +536,10 @@ TRUE (1) for a response of YES or FALSE (0) for anything else.
 
 =back
 
-=back
-
 =over 2
 
+=back
+
 =head2 msgbox( )
 
 =over 4
@@ -563,10 +570,10 @@ TRUE (1) for a response of OK or FALSE (0) for anything else.
 
 =back
 
-=back
-
 =over 2
 
+=back
+
 =head2 inputbox( )
 
 =over 4
@@ -598,10 +605,10 @@ a SCALAR if the response is OK and FALSE (0) for anything else.
 
 =back
 
-=back
-
 =over 2
 
+=back
+
 =head2 password( )
 
 =over 4
@@ -636,10 +643,10 @@ a SCALAR if the response is OK and FALSE (0) for anything else.
 
 =back
 
-=back
-
 =over 2
 
+=back
+
 =head2 textbox( )
 
 =over 4
@@ -671,10 +678,10 @@ TRUE (1) if the response is OK and FALSE (0) for anything else.
 
 =back
 
-=back
-
 =over 2
 
+=back
+
 =head2 menu( )
 
 =over 4
@@ -709,10 +716,10 @@ anything else.
 
 =back
 
-=back
-
 =over 2
 
+=back
+
 =head2 checklist( )
 
 =over 4
@@ -748,10 +755,10 @@ anything else.
 
 =back
 
-=back
-
 =over 2
 
+=back
+
 =head2 radiolist( )
 
 =over 4
@@ -787,10 +794,10 @@ anything else.
 
 =back
 
-=back
-
 =over 2
 
+=back
+
 =head2 fselect( )
 
 =over 4
@@ -821,10 +828,10 @@ a SCALAR if the response is OK and FALSE (0) for anything else.
 
 =back
 
-=back
-
 =over 2
 
+=back
+
 =head2 dselect( )
 
 =over 4
@@ -856,14 +863,12 @@ a SCALAR if the response is OK and FALSE (0) for anything else.
 
 =back
 
-=back
-
 =head1 SEE ALSO
 
-=item PERLDOC
-
 =over 2
 
+=item PERLDOC
+
  UI::Dialog::GNOME
  UI::Dialog::KDE
  UI::Dialog::Console
@@ -880,10 +885,10 @@ a SCALAR if the response is OK and FALSE (0) for anything else.
 
 =back
 
-=item MAN FILES
-
 =over 2
 
+=item MAN FILES
+
  dialog(1), whiptail(1), zenity(1), gdialog(1), Xdialog(1),
  osd_cat(1), kdialog(1) and nautilus(1)
 
@@ -896,11 +901,11 @@ module in the subject line.
 
 =head1 AUTHOR
 
-Kevin C. Krinke, E<lt>kckrinke@opendoorsoftware.comE<gt>
+Kevin C. Krinke, E<lt>kevin@krinke.caE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
- Copyright (C) 2004  Kevin C. Krinke <kckrinke@opendoorsoftware.com>
+ Copyright (C) 2015  Kevin C. Krinke <kevin@krinke.ca>
 
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
