@@ -1,4 +1,21 @@
 package UI::Dialog::Screen::Menu;
+###############################################################################
+#  Copyright (C) 2015  Kevin C. Krinke <kevin@krinke.ca>
+#
+#  This library is free software; you can redistribute it and/or
+#  modify it under the terms of the GNU Lesser General Public
+#  License as published by the Free Software Foundation; either
+#  version 2.1 of the License, or (at your option) any later version.
+#
+#  This library is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+#  Lesser General Public License for more details.
+#
+#  You should have received a copy of the GNU Lesser General Public
+#  License along with this library; if not, write to the Free Software
+#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+###############################################################################
 use strict;
 use warnings;
 use diagnostics;
@@ -6,7 +23,7 @@ use constant { TRUE => 1, FALSE => 0 };
 
 BEGIN {
     use vars qw($VERSION);
-    $VERSION = '1.09';
+    $VERSION = '1.11';
 }
 
 use UI::Dialog;
@@ -33,6 +50,7 @@ sub new {
           PATH => (defined $args{PATH}) ? $args{PATH} : undef,
           beepbefore => (defined $args{beepbefore}) ? $args{beepbefore} : undef,
           beepafter => (defined $args{beepafter}) ? $args{beepafter} : undef,
+          'trust-input' => ($args{'trust-input'}==1) ? 1 : 0,
          );
     }
     unless (exists $args{menu}) {
